@@ -10,7 +10,7 @@ def dt64_to_dt(dt64):
     t2 = datetime.datetime(t1.year, t1.month, t1.day, t1.hour, t1.minute, t1.second)
     return t2
 
-def days2events(days):
+def days2events(days, gap=1):
     """
     Parameters
     ----------
@@ -29,7 +29,7 @@ def days2events(days):
             tdk = days[k]
             ddk = (days[k]-days[k-1]).days
             
-            if ddk==1:
+            if ddk<=gap:
                 evek.append(tdk)
             else:
                 eve.append(evek)
